from QS import QS
QS()